# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.live_chat_message_list_response import LiveChatMessageListResponse

class TestLiveChatMessageListResponse(unittest.TestCase):
    """LiveChatMessageListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LiveChatMessageListResponse:
        """Test LiveChatMessageListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LiveChatMessageListResponse`
        """
        model = LiveChatMessageListResponse()
        if include_optional:
            return LiveChatMessageListResponse(
                active_poll_item = youtube_ti.models.live_chat_message.LiveChatMessage(
                    author_details = youtube_ti.models.live_chat_message_author_details.LiveChatMessageAuthorDetails(
                        channel_id = '', 
                        channel_url = '', 
                        display_name = '', 
                        is_chat_moderator = True, 
                        is_chat_owner = True, 
                        is_chat_sponsor = True, 
                        is_verified = True, 
                        profile_image_url = '', ), 
                    etag = '', 
                    id = '', 
                    kind = 'youtube#liveChatMessage', 
                    snippet = youtube_ti.models.live_chat_message_snippet.LiveChatMessageSnippet(
                        author_channel_id = '', 
                        display_message = '', 
                        fan_funding_event_details = youtube_ti.models.live_chat_fan_funding_event_details.LiveChatFanFundingEventDetails(
                            amount_display_string = '', 
                            amount_micros = '', 
                            currency = '', 
                            user_comment = '', ), 
                        gift_membership_received_details = youtube_ti.models.live_chat_gift_membership_received_details.LiveChatGiftMembershipReceivedDetails(
                            associated_membership_gifting_message_id = '', 
                            gifter_channel_id = '', 
                            member_level_name = '', ), 
                        has_display_content = True, 
                        live_chat_id = '', 
                        member_milestone_chat_details = youtube_ti.models.live_chat_member_milestone_chat_details.LiveChatMemberMilestoneChatDetails(
                            member_level_name = '', 
                            member_month = 56, 
                            user_comment = '', ), 
                        membership_gifting_details = youtube_ti.models.live_chat_membership_gifting_details.LiveChatMembershipGiftingDetails(
                            gift_memberships_count = 56, 
                            gift_memberships_level_name = '', ), 
                        message_deleted_details = youtube_ti.models.live_chat_message_deleted_details.LiveChatMessageDeletedDetails(
                            deleted_message_id = '', ), 
                        message_retracted_details = youtube_ti.models.live_chat_message_retracted_details.LiveChatMessageRetractedDetails(
                            retracted_message_id = '', ), 
                        new_sponsor_details = youtube_ti.models.live_chat_new_sponsor_details.LiveChatNewSponsorDetails(
                            is_upgrade = True, 
                            member_level_name = '', ), 
                        poll_details = youtube_ti.models.live_chat_poll_details.LiveChatPollDetails(
                            metadata = youtube_ti.models.live_chat_poll_details_poll_metadata.LiveChatPollDetailsPollMetadata(
                                options = [
                                    youtube_ti.models.live_chat_poll_details_poll_metadata_poll_option.LiveChatPollDetailsPollMetadataPollOption(
                                        option_text = '', 
                                        tally = '', )
                                    ], 
                                question_text = '', ), 
                            status = 'unknown', ), 
                        published_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        super_chat_details = youtube_ti.models.live_chat_super_chat_details.LiveChatSuperChatDetails(
                            amount_display_string = '', 
                            amount_micros = '', 
                            currency = '', 
                            tier = 56, 
                            user_comment = '', ), 
                        super_sticker_details = youtube_ti.models.live_chat_super_sticker_details.LiveChatSuperStickerDetails(
                            amount_display_string = '', 
                            amount_micros = '', 
                            currency = '', 
                            super_sticker_metadata = youtube_ti.models.super_sticker_metadata.SuperStickerMetadata(
                                alt_text = '', 
                                alt_text_language = '', 
                                sticker_id = '', ), 
                            tier = 56, ), 
                        text_message_details = youtube_ti.models.live_chat_text_message_details.LiveChatTextMessageDetails(
                            message_text = '', ), 
                        type = 'invalidType', 
                        user_banned_details = youtube_ti.models.live_chat_user_banned_message_details.LiveChatUserBannedMessageDetails(
                            ban_duration_seconds = '', 
                            ban_type = 'permanent', 
                            banned_user_details = youtube_ti.models.channel_profile_details.ChannelProfileDetails(
                                channel_id = '', 
                                channel_url = '', 
                                display_name = '', 
                                profile_image_url = '', ), ), ), ),
                etag = '',
                event_id = '',
                items = [
                    youtube_ti.models.live_chat_message.LiveChatMessage(
                        author_details = youtube_ti.models.live_chat_message_author_details.LiveChatMessageAuthorDetails(
                            channel_id = '', 
                            channel_url = '', 
                            display_name = '', 
                            is_chat_moderator = True, 
                            is_chat_owner = True, 
                            is_chat_sponsor = True, 
                            is_verified = True, 
                            profile_image_url = '', ), 
                        etag = '', 
                        id = '', 
                        kind = 'youtube#liveChatMessage', 
                        snippet = youtube_ti.models.live_chat_message_snippet.LiveChatMessageSnippet(
                            author_channel_id = '', 
                            display_message = '', 
                            fan_funding_event_details = youtube_ti.models.live_chat_fan_funding_event_details.LiveChatFanFundingEventDetails(
                                amount_display_string = '', 
                                amount_micros = '', 
                                currency = '', 
                                user_comment = '', ), 
                            gift_membership_received_details = youtube_ti.models.live_chat_gift_membership_received_details.LiveChatGiftMembershipReceivedDetails(
                                associated_membership_gifting_message_id = '', 
                                gifter_channel_id = '', 
                                member_level_name = '', ), 
                            has_display_content = True, 
                            live_chat_id = '', 
                            member_milestone_chat_details = youtube_ti.models.live_chat_member_milestone_chat_details.LiveChatMemberMilestoneChatDetails(
                                member_level_name = '', 
                                member_month = 56, 
                                user_comment = '', ), 
                            membership_gifting_details = youtube_ti.models.live_chat_membership_gifting_details.LiveChatMembershipGiftingDetails(
                                gift_memberships_count = 56, 
                                gift_memberships_level_name = '', ), 
                            message_deleted_details = youtube_ti.models.live_chat_message_deleted_details.LiveChatMessageDeletedDetails(
                                deleted_message_id = '', ), 
                            message_retracted_details = youtube_ti.models.live_chat_message_retracted_details.LiveChatMessageRetractedDetails(
                                retracted_message_id = '', ), 
                            new_sponsor_details = youtube_ti.models.live_chat_new_sponsor_details.LiveChatNewSponsorDetails(
                                is_upgrade = True, 
                                member_level_name = '', ), 
                            poll_details = youtube_ti.models.live_chat_poll_details.LiveChatPollDetails(
                                metadata = youtube_ti.models.live_chat_poll_details_poll_metadata.LiveChatPollDetailsPollMetadata(
                                    options = [
                                        youtube_ti.models.live_chat_poll_details_poll_metadata_poll_option.LiveChatPollDetailsPollMetadataPollOption(
                                            option_text = '', 
                                            tally = '', )
                                        ], 
                                    question_text = '', ), 
                                status = 'unknown', ), 
                            published_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            super_chat_details = youtube_ti.models.live_chat_super_chat_details.LiveChatSuperChatDetails(
                                amount_display_string = '', 
                                amount_micros = '', 
                                currency = '', 
                                tier = 56, 
                                user_comment = '', ), 
                            super_sticker_details = youtube_ti.models.live_chat_super_sticker_details.LiveChatSuperStickerDetails(
                                amount_display_string = '', 
                                amount_micros = '', 
                                currency = '', 
                                super_sticker_metadata = youtube_ti.models.super_sticker_metadata.SuperStickerMetadata(
                                    alt_text = '', 
                                    alt_text_language = '', 
                                    sticker_id = '', ), 
                                tier = 56, ), 
                            text_message_details = youtube_ti.models.live_chat_text_message_details.LiveChatTextMessageDetails(
                                message_text = '', ), 
                            type = 'invalidType', 
                            user_banned_details = youtube_ti.models.live_chat_user_banned_message_details.LiveChatUserBannedMessageDetails(
                                ban_duration_seconds = '', 
                                ban_type = 'permanent', 
                                banned_user_details = youtube_ti.models.channel_profile_details.ChannelProfileDetails(
                                    channel_id = '', 
                                    channel_url = '', 
                                    display_name = '', 
                                    profile_image_url = '', ), ), ), )
                    ],
                kind = 'youtube#liveChatMessageListResponse',
                next_page_token = '',
                offline_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                page_info = youtube_ti.models.page_info.PageInfo(
                    results_per_page = 56, 
                    total_results = 56, ),
                polling_interval_millis = 56,
                token_pagination = None,
                visitor_id = ''
            )
        else:
            return LiveChatMessageListResponse(
        )
        """

    def testLiveChatMessageListResponse(self):
        """Test LiveChatMessageListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from youtube_ti.models.access_policy import AccessPolicy
from youtube_ti.models.content_rating import ContentRating
from youtube_ti.models.video_content_details_region_restriction import VideoContentDetailsRegionRestriction
from typing import Optional, Set
from typing_extensions import Self

class VideoContentDetails(BaseModel):
    """
    Details about the content of a YouTube Video.
    """ # noqa: E501
    caption: Optional[StrictStr] = Field(default=None, description="The value of captions indicates whether the video has captions or not.")
    content_rating: Optional[ContentRating] = Field(default=None, alias="contentRating")
    country_restriction: Optional[AccessPolicy] = Field(default=None, alias="countryRestriction")
    definition: Optional[StrictStr] = Field(default=None, description="The value of definition indicates whether the video is available in high definition or only in standard definition.")
    dimension: Optional[StrictStr] = Field(default=None, description="The value of dimension indicates whether the video is available in 3D or in 2D.")
    duration: Optional[StrictStr] = Field(default=None, description="The length of the video. The tag value is an ISO 8601 duration in the format PT#M#S, in which the letters PT indicate that the value specifies a period of time, and the letters M and S refer to length in minutes and seconds, respectively. The # characters preceding the M and S letters are both integers that specify the number of minutes (or seconds) of the video. For example, a value of PT15M51S indicates that the video is 15 minutes and 51 seconds long.")
    has_custom_thumbnail: Optional[StrictBool] = Field(default=None, description="Indicates whether the video uploader has provided a custom thumbnail image for the video. This property is only visible to the video uploader.", alias="hasCustomThumbnail")
    licensed_content: Optional[StrictBool] = Field(default=None, description="The value of is_license_content indicates whether the video is licensed content.", alias="licensedContent")
    projection: Optional[StrictStr] = Field(default=None, description="Specifies the projection format of the video.")
    region_restriction: Optional[VideoContentDetailsRegionRestriction] = Field(default=None, alias="regionRestriction")
    __properties: ClassVar[List[str]] = ["caption", "contentRating", "countryRestriction", "definition", "dimension", "duration", "hasCustomThumbnail", "licensedContent", "projection", "regionRestriction"]

    @field_validator('caption')
    def caption_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['true', 'false']):
            raise ValueError("must be one of enum values ('true', 'false')")
        return value

    @field_validator('definition')
    def definition_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['sd', 'hd']):
            raise ValueError("must be one of enum values ('sd', 'hd')")
        return value

    @field_validator('projection')
    def projection_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['rectangular', '360']):
            raise ValueError("must be one of enum values ('rectangular', '360')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VideoContentDetails from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of content_rating
        if self.content_rating:
            _dict['contentRating'] = self.content_rating.to_dict()
        # override the default output from pydantic by calling `to_dict()` of country_restriction
        if self.country_restriction:
            _dict['countryRestriction'] = self.country_restriction.to_dict()
        # override the default output from pydantic by calling `to_dict()` of region_restriction
        if self.region_restriction:
            _dict['regionRestriction'] = self.region_restriction.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VideoContentDetails from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "caption": obj.get("caption"),
            "contentRating": ContentRating.from_dict(obj["contentRating"]) if obj.get("contentRating") is not None else None,
            "countryRestriction": AccessPolicy.from_dict(obj["countryRestriction"]) if obj.get("countryRestriction") is not None else None,
            "definition": obj.get("definition"),
            "dimension": obj.get("dimension"),
            "duration": obj.get("duration"),
            "hasCustomThumbnail": obj.get("hasCustomThumbnail"),
            "licensedContent": obj.get("licensedContent"),
            "projection": obj.get("projection"),
            "regionRestriction": VideoContentDetailsRegionRestriction.from_dict(obj["regionRestriction"]) if obj.get("regionRestriction") is not None else None
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from youtube_ti.models.live_chat_fan_funding_event_details import LiveChatFanFundingEventDetails
from youtube_ti.models.live_chat_gift_membership_received_details import LiveChatGiftMembershipReceivedDetails
from youtube_ti.models.live_chat_member_milestone_chat_details import LiveChatMemberMilestoneChatDetails
from youtube_ti.models.live_chat_membership_gifting_details import LiveChatMembershipGiftingDetails
from youtube_ti.models.live_chat_message_deleted_details import LiveChatMessageDeletedDetails
from youtube_ti.models.live_chat_message_retracted_details import LiveChatMessageRetractedDetails
from youtube_ti.models.live_chat_new_sponsor_details import LiveChatNewSponsorDetails
from youtube_ti.models.live_chat_poll_details import LiveChatPollDetails
from youtube_ti.models.live_chat_super_chat_details import LiveChatSuperChatDetails
from youtube_ti.models.live_chat_super_sticker_details import LiveChatSuperStickerDetails
from youtube_ti.models.live_chat_text_message_details import LiveChatTextMessageDetails
from youtube_ti.models.live_chat_user_banned_message_details import LiveChatUserBannedMessageDetails
from typing import Optional, Set
from typing_extensions import Self

class LiveChatMessageSnippet(BaseModel):
    """
    Next ID: 34
    """ # noqa: E501
    author_channel_id: Optional[StrictStr] = Field(default=None, description="The ID of the user that authored this message, this field is not always filled. textMessageEvent - the user that wrote the message fanFundingEvent - the user that funded the broadcast newSponsorEvent - the user that just became a sponsor memberMilestoneChatEvent - the member that sent the message membershipGiftingEvent - the user that made the purchase giftMembershipReceivedEvent - the user that received the gift membership messageDeletedEvent - the moderator that took the action messageRetractedEvent - the author that retracted their message userBannedEvent - the moderator that took the action superChatEvent - the user that made the purchase superStickerEvent - the user that made the purchase pollEvent - the user that created the poll", alias="authorChannelId")
    display_message: Optional[StrictStr] = Field(default=None, description="Contains a string that can be displayed to the user. If this field is not present the message is silent, at the moment only messages of type TOMBSTONE and CHAT_ENDED_EVENT are silent.", alias="displayMessage")
    fan_funding_event_details: Optional[LiveChatFanFundingEventDetails] = Field(default=None, alias="fanFundingEventDetails")
    gift_membership_received_details: Optional[LiveChatGiftMembershipReceivedDetails] = Field(default=None, alias="giftMembershipReceivedDetails")
    has_display_content: Optional[StrictBool] = Field(default=None, description="Whether the message has display content that should be displayed to users.", alias="hasDisplayContent")
    live_chat_id: Optional[StrictStr] = Field(default=None, alias="liveChatId")
    member_milestone_chat_details: Optional[LiveChatMemberMilestoneChatDetails] = Field(default=None, alias="memberMilestoneChatDetails")
    membership_gifting_details: Optional[LiveChatMembershipGiftingDetails] = Field(default=None, alias="membershipGiftingDetails")
    message_deleted_details: Optional[LiveChatMessageDeletedDetails] = Field(default=None, alias="messageDeletedDetails")
    message_retracted_details: Optional[LiveChatMessageRetractedDetails] = Field(default=None, alias="messageRetractedDetails")
    new_sponsor_details: Optional[LiveChatNewSponsorDetails] = Field(default=None, alias="newSponsorDetails")
    poll_details: Optional[LiveChatPollDetails] = Field(default=None, alias="pollDetails")
    published_at: Optional[datetime] = Field(default=None, description="The date and time when the message was orignally published.", alias="publishedAt")
    super_chat_details: Optional[LiveChatSuperChatDetails] = Field(default=None, alias="superChatDetails")
    super_sticker_details: Optional[LiveChatSuperStickerDetails] = Field(default=None, alias="superStickerDetails")
    text_message_details: Optional[LiveChatTextMessageDetails] = Field(default=None, alias="textMessageDetails")
    type: Optional[StrictStr] = Field(default=None, description="The type of message, this will always be present, it determines the contents of the message as well as which fields will be present.")
    user_banned_details: Optional[LiveChatUserBannedMessageDetails] = Field(default=None, alias="userBannedDetails")
    __properties: ClassVar[List[str]] = ["authorChannelId", "displayMessage", "fanFundingEventDetails", "giftMembershipReceivedDetails", "hasDisplayContent", "liveChatId", "memberMilestoneChatDetails", "membershipGiftingDetails", "messageDeletedDetails", "messageRetractedDetails", "newSponsorDetails", "pollDetails", "publishedAt", "superChatDetails", "superStickerDetails", "textMessageDetails", "type", "userBannedDetails"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['invalidType', 'textMessageEvent', 'tombstone', 'fanFundingEvent', 'chatEndedEvent', 'sponsorOnlyModeStartedEvent', 'sponsorOnlyModeEndedEvent', 'newSponsorEvent', 'memberMilestoneChatEvent', 'membershipGiftingEvent', 'giftMembershipReceivedEvent', 'messageDeletedEvent', 'messageRetractedEvent', 'userBannedEvent', 'superChatEvent', 'superStickerEvent', 'pollEvent']):
            raise ValueError("must be one of enum values ('invalidType', 'textMessageEvent', 'tombstone', 'fanFundingEvent', 'chatEndedEvent', 'sponsorOnlyModeStartedEvent', 'sponsorOnlyModeEndedEvent', 'newSponsorEvent', 'memberMilestoneChatEvent', 'membershipGiftingEvent', 'giftMembershipReceivedEvent', 'messageDeletedEvent', 'messageRetractedEvent', 'userBannedEvent', 'superChatEvent', 'superStickerEvent', 'pollEvent')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of LiveChatMessageSnippet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of fan_funding_event_details
        if self.fan_funding_event_details:
            _dict['fanFundingEventDetails'] = self.fan_funding_event_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of gift_membership_received_details
        if self.gift_membership_received_details:
            _dict['giftMembershipReceivedDetails'] = self.gift_membership_received_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of member_milestone_chat_details
        if self.member_milestone_chat_details:
            _dict['memberMilestoneChatDetails'] = self.member_milestone_chat_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of membership_gifting_details
        if self.membership_gifting_details:
            _dict['membershipGiftingDetails'] = self.membership_gifting_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of message_deleted_details
        if self.message_deleted_details:
            _dict['messageDeletedDetails'] = self.message_deleted_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of message_retracted_details
        if self.message_retracted_details:
            _dict['messageRetractedDetails'] = self.message_retracted_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of new_sponsor_details
        if self.new_sponsor_details:
            _dict['newSponsorDetails'] = self.new_sponsor_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of poll_details
        if self.poll_details:
            _dict['pollDetails'] = self.poll_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of super_chat_details
        if self.super_chat_details:
            _dict['superChatDetails'] = self.super_chat_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of super_sticker_details
        if self.super_sticker_details:
            _dict['superStickerDetails'] = self.super_sticker_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of text_message_details
        if self.text_message_details:
            _dict['textMessageDetails'] = self.text_message_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of user_banned_details
        if self.user_banned_details:
            _dict['userBannedDetails'] = self.user_banned_details.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of LiveChatMessageSnippet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "authorChannelId": obj.get("authorChannelId"),
            "displayMessage": obj.get("displayMessage"),
            "fanFundingEventDetails": LiveChatFanFundingEventDetails.from_dict(obj["fanFundingEventDetails"]) if obj.get("fanFundingEventDetails") is not None else None,
            "giftMembershipReceivedDetails": LiveChatGiftMembershipReceivedDetails.from_dict(obj["giftMembershipReceivedDetails"]) if obj.get("giftMembershipReceivedDetails") is not None else None,
            "hasDisplayContent": obj.get("hasDisplayContent"),
            "liveChatId": obj.get("liveChatId"),
            "memberMilestoneChatDetails": LiveChatMemberMilestoneChatDetails.from_dict(obj["memberMilestoneChatDetails"]) if obj.get("memberMilestoneChatDetails") is not None else None,
            "membershipGiftingDetails": LiveChatMembershipGiftingDetails.from_dict(obj["membershipGiftingDetails"]) if obj.get("membershipGiftingDetails") is not None else None,
            "messageDeletedDetails": LiveChatMessageDeletedDetails.from_dict(obj["messageDeletedDetails"]) if obj.get("messageDeletedDetails") is not None else None,
            "messageRetractedDetails": LiveChatMessageRetractedDetails.from_dict(obj["messageRetractedDetails"]) if obj.get("messageRetractedDetails") is not None else None,
            "newSponsorDetails": LiveChatNewSponsorDetails.from_dict(obj["newSponsorDetails"]) if obj.get("newSponsorDetails") is not None else None,
            "pollDetails": LiveChatPollDetails.from_dict(obj["pollDetails"]) if obj.get("pollDetails") is not None else None,
            "publishedAt": obj.get("publishedAt"),
            "superChatDetails": LiveChatSuperChatDetails.from_dict(obj["superChatDetails"]) if obj.get("superChatDetails") is not None else None,
            "superStickerDetails": LiveChatSuperStickerDetails.from_dict(obj["superStickerDetails"]) if obj.get("superStickerDetails") is not None else None,
            "textMessageDetails": LiveChatTextMessageDetails.from_dict(obj["textMessageDetails"]) if obj.get("textMessageDetails") is not None else None,
            "type": obj.get("type"),
            "userBannedDetails": LiveChatUserBannedMessageDetails.from_dict(obj["userBannedDetails"]) if obj.get("userBannedDetails") is not None else None
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.third_party_link_list_response import ThirdPartyLinkListResponse

class TestThirdPartyLinkListResponse(unittest.TestCase):
    """ThirdPartyLinkListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ThirdPartyLinkListResponse:
        """Test ThirdPartyLinkListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ThirdPartyLinkListResponse`
        """
        model = ThirdPartyLinkListResponse()
        if include_optional:
            return ThirdPartyLinkListResponse(
                etag = '',
                items = [
                    youtube_ti.models.third_party_link.ThirdPartyLink(
                        etag = '', 
                        kind = 'youtube#thirdPartyLink', 
                        linking_token = '', 
                        snippet = youtube_ti.models.third_party_link_snippet.ThirdPartyLinkSnippet(
                            channel_to_store_link = youtube_ti.models.channel_to_store_link_details.ChannelToStoreLinkDetails(
                                billing_details = youtube_ti.models.channel_to_store_link_details_billing_details.ChannelToStoreLinkDetailsBillingDetails(
                                    billing_status = 'billingStatusUnspecified', ), 
                                merchant_affiliate_program_details = youtube_ti.models.channel_to_store_link_details_merchant_affiliate_program_details.ChannelToStoreLinkDetailsMerchantAffiliateProgramDetails(
                                    status = 'merchantAffiliateProgramStatusUnspecified', ), 
                                merchant_id = '', 
                                store_name = '', 
                                store_url = '', ), 
                            type = 'linkUnspecified', ), 
                        status = youtube_ti.models.third_party_link_status.ThirdPartyLinkStatus(
                            link_status = 'unknown', ), )
                    ],
                kind = 'youtube#thirdPartyLinkListResponse'
            )
        else:
            return ThirdPartyLinkListResponse(
        )
        """

    def testThirdPartyLinkListResponse(self):
        """Test ThirdPartyLinkListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class VideoStatus(BaseModel):
    """
    Basic details about a video category, such as its localized title. Next Id: 19
    """ # noqa: E501
    contains_synthetic_media: Optional[StrictBool] = Field(default=None, description="Indicates if the video contains altered or synthetic media.", alias="containsSyntheticMedia")
    embeddable: Optional[StrictBool] = Field(default=None, description="This value indicates if the video can be embedded on another website. @mutable youtube.videos.insert youtube.videos.update")
    failure_reason: Optional[StrictStr] = Field(default=None, description="This value explains why a video failed to upload. This property is only present if the uploadStatus property indicates that the upload failed.", alias="failureReason")
    license: Optional[StrictStr] = Field(default=None, description="The video's license. @mutable youtube.videos.insert youtube.videos.update")
    made_for_kids: Optional[StrictBool] = Field(default=None, alias="madeForKids")
    privacy_status: Optional[StrictStr] = Field(default=None, description="The video's privacy status.", alias="privacyStatus")
    public_stats_viewable: Optional[StrictBool] = Field(default=None, description="This value indicates if the extended video statistics on the watch page can be viewed by everyone. Note that the view count, likes, etc will still be visible if this is disabled. @mutable youtube.videos.insert youtube.videos.update", alias="publicStatsViewable")
    publish_at: Optional[datetime] = Field(default=None, description="The date and time when the video is scheduled to publish. It can be set only if the privacy status of the video is private..", alias="publishAt")
    rejection_reason: Optional[StrictStr] = Field(default=None, description="This value explains why YouTube rejected an uploaded video. This property is only present if the uploadStatus property indicates that the upload was rejected.", alias="rejectionReason")
    self_declared_made_for_kids: Optional[StrictBool] = Field(default=None, alias="selfDeclaredMadeForKids")
    upload_status: Optional[StrictStr] = Field(default=None, description="The status of the uploaded video.", alias="uploadStatus")
    __properties: ClassVar[List[str]] = ["containsSyntheticMedia", "embeddable", "failureReason", "license", "madeForKids", "privacyStatus", "publicStatsViewable", "publishAt", "rejectionReason", "selfDeclaredMadeForKids", "uploadStatus"]

    @field_validator('failure_reason')
    def failure_reason_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['conversion', 'invalidFile', 'emptyFile', 'tooSmall', 'codec', 'uploadAborted']):
            raise ValueError("must be one of enum values ('conversion', 'invalidFile', 'emptyFile', 'tooSmall', 'codec', 'uploadAborted')")
        return value

    @field_validator('license')
    def license_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['youtube', 'creativeCommon']):
            raise ValueError("must be one of enum values ('youtube', 'creativeCommon')")
        return value

    @field_validator('privacy_status')
    def privacy_status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['public', 'unlisted', 'private']):
            raise ValueError("must be one of enum values ('public', 'unlisted', 'private')")
        return value

    @field_validator('rejection_reason')
    def rejection_reason_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['copyright', 'inappropriate', 'duplicate', 'termsOfUse', 'uploaderAccountSuspended', 'length', 'claim', 'uploaderAccountClosed', 'trademark', 'legal']):
            raise ValueError("must be one of enum values ('copyright', 'inappropriate', 'duplicate', 'termsOfUse', 'uploaderAccountSuspended', 'length', 'claim', 'uploaderAccountClosed', 'trademark', 'legal')")
        return value

    @field_validator('upload_status')
    def upload_status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['uploaded', 'processed', 'failed', 'rejected', 'deleted']):
            raise ValueError("must be one of enum values ('uploaded', 'processed', 'failed', 'rejected', 'deleted')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VideoStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VideoStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "containsSyntheticMedia": obj.get("containsSyntheticMedia"),
            "embeddable": obj.get("embeddable"),
            "failureReason": obj.get("failureReason"),
            "license": obj.get("license"),
            "madeForKids": obj.get("madeForKids"),
            "privacyStatus": obj.get("privacyStatus"),
            "publicStatsViewable": obj.get("publicStatsViewable"),
            "publishAt": obj.get("publishAt"),
            "rejectionReason": obj.get("rejectionReason"),
            "selfDeclaredMadeForKids": obj.get("selfDeclaredMadeForKids"),
            "uploadStatus": obj.get("uploadStatus")
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.playlist_item import PlaylistItem

class TestPlaylistItem(unittest.TestCase):
    """PlaylistItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PlaylistItem:
        """Test PlaylistItem
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PlaylistItem`
        """
        model = PlaylistItem()
        if include_optional:
            return PlaylistItem(
                content_details = youtube_ti.models.playlist_item_content_details.PlaylistItemContentDetails(
                    end_at = '', 
                    note = '', 
                    start_at = '', 
                    video_id = '', 
                    video_published_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                etag = '',
                id = '',
                kind = 'youtube#playlistItem',
                snippet = youtube_ti.models.playlist_item_snippet.PlaylistItemSnippet(
                    channel_id = '', 
                    channel_title = '', 
                    description = '', 
                    playlist_id = '', 
                    position = 56, 
                    published_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    resource_id = youtube_ti.models.resource_id.ResourceId(
                        channel_id = '', 
                        kind = '', 
                        playlist_id = '', 
                        video_id = '', ), 
                    thumbnails = youtube_ti.models.thumbnail_details.ThumbnailDetails(
                        default = youtube_ti.models.thumbnail.Thumbnail(
                            height = 56, 
                            url = '', 
                            width = 56, ), 
                        high = youtube_ti.models.thumbnail.Thumbnail(
                            height = 56, 
                            url = '', 
                            width = 56, ), 
                        maxres = , 
                        medium = , 
                        standard = , ), 
                    title = '', 
                    video_owner_channel_id = '', 
                    video_owner_channel_title = '', ),
                status = youtube_ti.models.playlist_item_status.PlaylistItemStatus(
                    privacy_status = 'public', )
            )
        else:
            return PlaylistItem(
        )
        """

    def testPlaylistItem(self):
        """Test PlaylistItem"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from youtube_ti.models.activity_content_details_bulletin import ActivityContentDetailsBulletin
from youtube_ti.models.activity_content_details_channel_item import ActivityContentDetailsChannelItem
from youtube_ti.models.activity_content_details_comment import ActivityContentDetailsComment
from youtube_ti.models.activity_content_details_favorite import ActivityContentDetailsFavorite
from youtube_ti.models.activity_content_details_like import ActivityContentDetailsLike
from youtube_ti.models.activity_content_details_playlist_item import ActivityContentDetailsPlaylistItem
from youtube_ti.models.activity_content_details_promoted_item import ActivityContentDetailsPromotedItem
from youtube_ti.models.activity_content_details_recommendation import ActivityContentDetailsRecommendation
from youtube_ti.models.activity_content_details_social import ActivityContentDetailsSocial
from youtube_ti.models.activity_content_details_subscription import ActivityContentDetailsSubscription
from youtube_ti.models.activity_content_details_upload import ActivityContentDetailsUpload
from typing import Optional, Set
from typing_extensions import Self

class ActivityContentDetails(BaseModel):
    """
    Details about the content of an activity: the video that was shared, the channel that was subscribed to, etc.
    """ # noqa: E501
    bulletin: Optional[ActivityContentDetailsBulletin] = None
    channel_item: Optional[ActivityContentDetailsChannelItem] = Field(default=None, alias="channelItem")
    comment: Optional[ActivityContentDetailsComment] = None
    favorite: Optional[ActivityContentDetailsFavorite] = None
    like: Optional[ActivityContentDetailsLike] = None
    playlist_item: Optional[ActivityContentDetailsPlaylistItem] = Field(default=None, alias="playlistItem")
    promoted_item: Optional[ActivityContentDetailsPromotedItem] = Field(default=None, alias="promotedItem")
    recommendation: Optional[ActivityContentDetailsRecommendation] = None
    social: Optional[ActivityContentDetailsSocial] = None
    subscription: Optional[ActivityContentDetailsSubscription] = None
    upload: Optional[ActivityContentDetailsUpload] = None
    __properties: ClassVar[List[str]] = ["bulletin", "channelItem", "comment", "favorite", "like", "playlistItem", "promotedItem", "recommendation", "social", "subscription", "upload"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ActivityContentDetails from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of bulletin
        if self.bulletin:
            _dict['bulletin'] = self.bulletin.to_dict()
        # override the default output from pydantic by calling `to_dict()` of channel_item
        if self.channel_item:
            _dict['channelItem'] = self.channel_item.to_dict()
        # override the default output from pydantic by calling `to_dict()` of comment
        if self.comment:
            _dict['comment'] = self.comment.to_dict()
        # override the default output from pydantic by calling `to_dict()` of favorite
        if self.favorite:
            _dict['favorite'] = self.favorite.to_dict()
        # override the default output from pydantic by calling `to_dict()` of like
        if self.like:
            _dict['like'] = self.like.to_dict()
        # override the default output from pydantic by calling `to_dict()` of playlist_item
        if self.playlist_item:
            _dict['playlistItem'] = self.playlist_item.to_dict()
        # override the default output from pydantic by calling `to_dict()` of promoted_item
        if self.promoted_item:
            _dict['promotedItem'] = self.promoted_item.to_dict()
        # override the default output from pydantic by calling `to_dict()` of recommendation
        if self.recommendation:
            _dict['recommendation'] = self.recommendation.to_dict()
        # override the default output from pydantic by calling `to_dict()` of social
        if self.social:
            _dict['social'] = self.social.to_dict()
        # override the default output from pydantic by calling `to_dict()` of subscription
        if self.subscription:
            _dict['subscription'] = self.subscription.to_dict()
        # override the default output from pydantic by calling `to_dict()` of upload
        if self.upload:
            _dict['upload'] = self.upload.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ActivityContentDetails from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "bulletin": ActivityContentDetailsBulletin.from_dict(obj["bulletin"]) if obj.get("bulletin") is not None else None,
            "channelItem": ActivityContentDetailsChannelItem.from_dict(obj["channelItem"]) if obj.get("channelItem") is not None else None,
            "comment": ActivityContentDetailsComment.from_dict(obj["comment"]) if obj.get("comment") is not None else None,
            "favorite": ActivityContentDetailsFavorite.from_dict(obj["favorite"]) if obj.get("favorite") is not None else None,
            "like": ActivityContentDetailsLike.from_dict(obj["like"]) if obj.get("like") is not None else None,
            "playlistItem": ActivityContentDetailsPlaylistItem.from_dict(obj["playlistItem"]) if obj.get("playlistItem") is not None else None,
            "promotedItem": ActivityContentDetailsPromotedItem.from_dict(obj["promotedItem"]) if obj.get("promotedItem") is not None else None,
            "recommendation": ActivityContentDetailsRecommendation.from_dict(obj["recommendation"]) if obj.get("recommendation") is not None else None,
            "social": ActivityContentDetailsSocial.from_dict(obj["social"]) if obj.get("social") is not None else None,
            "subscription": ActivityContentDetailsSubscription.from_dict(obj["subscription"]) if obj.get("subscription") is not None else None,
            "upload": ActivityContentDetailsUpload.from_dict(obj["upload"]) if obj.get("upload") is not None else None
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ChannelSettings(BaseModel):
    """
    Branding properties for the channel view.
    """ # noqa: E501
    country: Optional[StrictStr] = Field(default=None, description="The country of the channel.")
    default_language: Optional[StrictStr] = Field(default=None, alias="defaultLanguage")
    default_tab: Optional[StrictStr] = Field(default=None, description="Which content tab users should see when viewing the channel.", alias="defaultTab")
    description: Optional[StrictStr] = Field(default=None, description="Specifies the channel description.")
    featured_channels_title: Optional[StrictStr] = Field(default=None, description="Title for the featured channels tab.", alias="featuredChannelsTitle")
    featured_channels_urls: Optional[List[StrictStr]] = Field(default=None, description="The list of featured channels.", alias="featuredChannelsUrls")
    keywords: Optional[StrictStr] = Field(default=None, description="Lists keywords associated with the channel, comma-separated.")
    moderate_comments: Optional[StrictBool] = Field(default=None, description="Whether user-submitted comments left on the channel page need to be approved by the channel owner to be publicly visible.", alias="moderateComments")
    profile_color: Optional[StrictStr] = Field(default=None, description="A prominent color that can be rendered on this channel page.", alias="profileColor")
    show_browse_view: Optional[StrictBool] = Field(default=None, description="Whether the tab to browse the videos should be displayed.", alias="showBrowseView")
    show_related_channels: Optional[StrictBool] = Field(default=None, description="Whether related channels should be proposed.", alias="showRelatedChannels")
    title: Optional[StrictStr] = Field(default=None, description="Specifies the channel title.")
    tracking_analytics_account_id: Optional[StrictStr] = Field(default=None, description="The ID for a Google Analytics account to track and measure traffic to the channels.", alias="trackingAnalyticsAccountId")
    unsubscribed_trailer: Optional[StrictStr] = Field(default=None, description="The trailer of the channel, for users that are not subscribers.", alias="unsubscribedTrailer")
    __properties: ClassVar[List[str]] = ["country", "defaultLanguage", "defaultTab", "description", "featuredChannelsTitle", "featuredChannelsUrls", "keywords", "moderateComments", "profileColor", "showBrowseView", "showRelatedChannels", "title", "trackingAnalyticsAccountId", "unsubscribedTrailer"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ChannelSettings from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ChannelSettings from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "country": obj.get("country"),
            "defaultLanguage": obj.get("defaultLanguage"),
            "defaultTab": obj.get("defaultTab"),
            "description": obj.get("description"),
            "featuredChannelsTitle": obj.get("featuredChannelsTitle"),
            "featuredChannelsUrls": obj.get("featuredChannelsUrls"),
            "keywords": obj.get("keywords"),
            "moderateComments": obj.get("moderateComments"),
            "profileColor": obj.get("profileColor"),
            "showBrowseView": obj.get("showBrowseView"),
            "showRelatedChannels": obj.get("showRelatedChannels"),
            "title": obj.get("title"),
            "trackingAnalyticsAccountId": obj.get("trackingAnalyticsAccountId"),
            "unsubscribedTrailer": obj.get("unsubscribedTrailer")
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.thumbnail_set_response import ThumbnailSetResponse

class TestThumbnailSetResponse(unittest.TestCase):
    """ThumbnailSetResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ThumbnailSetResponse:
        """Test ThumbnailSetResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ThumbnailSetResponse`
        """
        model = ThumbnailSetResponse()
        if include_optional:
            return ThumbnailSetResponse(
                etag = '',
                event_id = '',
                items = [
                    youtube_ti.models.thumbnail_details.ThumbnailDetails(
                        default = youtube_ti.models.thumbnail.Thumbnail(
                            height = 56, 
                            url = '', 
                            width = 56, ), 
                        high = youtube_ti.models.thumbnail.Thumbnail(
                            height = 56, 
                            url = '', 
                            width = 56, ), 
                        maxres = , 
                        medium = , 
                        standard = , )
                    ],
                kind = 'youtube#thumbnailSetResponse',
                visitor_id = ''
            )
        else:
            return ThumbnailSetResponse(
        )
        """

    def testThumbnailSetResponse(self):
        """Test ThumbnailSetResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class InvideoTiming(BaseModel):
    """
    Describes a temporal position of a visual widget inside a video.
    """ # noqa: E501
    duration_ms: Optional[StrictStr] = Field(default=None, description="Defines the duration in milliseconds for which the promotion should be displayed. If missing, the client should use the default.", alias="durationMs")
    offset_ms: Optional[StrictStr] = Field(default=None, description="Defines the time at which the promotion will appear. Depending on the value of type the value of the offsetMs field will represent a time offset from the start or from the end of the video, expressed in milliseconds.", alias="offsetMs")
    type: Optional[StrictStr] = Field(default=None, description="Describes a timing type. If the value is offsetFromStart, then the offsetMs field represents an offset from the start of the video. If the value is offsetFromEnd, then the offsetMs field represents an offset from the end of the video.")
    __properties: ClassVar[List[str]] = ["durationMs", "offsetMs", "type"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['offsetFromStart', 'offsetFromEnd']):
            raise ValueError("must be one of enum values ('offsetFromStart', 'offsetFromEnd')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of InvideoTiming from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of InvideoTiming from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "durationMs": obj.get("durationMs"),
            "offsetMs": obj.get("offsetMs"),
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from youtube_ti.models.channel_profile_details import ChannelProfileDetails
from youtube_ti.models.super_sticker_metadata import SuperStickerMetadata
from typing import Optional, Set
from typing_extensions import Self

class SuperChatEventSnippet(BaseModel):
    """
    SuperChatEventSnippet
    """ # noqa: E501
    amount_micros: Optional[StrictStr] = Field(default=None, description="The purchase amount, in micros of the purchase currency. e.g., 1 is represented as 1000000.", alias="amountMicros")
    channel_id: Optional[StrictStr] = Field(default=None, description="Channel id where the event occurred.", alias="channelId")
    comment_text: Optional[StrictStr] = Field(default=None, description="The text contents of the comment left by the user.", alias="commentText")
    created_at: Optional[datetime] = Field(default=None, description="The date and time when the event occurred.", alias="createdAt")
    currency: Optional[StrictStr] = Field(default=None, description="The currency in which the purchase was made. ISO 4217.")
    display_string: Optional[StrictStr] = Field(default=None, description="A rendered string that displays the purchase amount and currency (e.g., \"$1.00\"). The string is rendered for the given language.", alias="displayString")
    is_super_sticker_event: Optional[StrictBool] = Field(default=None, description="True if this event is a Super Sticker event.", alias="isSuperStickerEvent")
    message_type: Optional[StrictInt] = Field(default=None, description="The tier for the paid message, which is based on the amount of money spent to purchase the message.", alias="messageType")
    super_sticker_metadata: Optional[SuperStickerMetadata] = Field(default=None, alias="superStickerMetadata")
    supporter_details: Optional[ChannelProfileDetails] = Field(default=None, alias="supporterDetails")
    __properties: ClassVar[List[str]] = ["amountMicros", "channelId", "commentText", "createdAt", "currency", "displayString", "isSuperStickerEvent", "messageType", "superStickerMetadata", "supporterDetails"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SuperChatEventSnippet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of super_sticker_metadata
        if self.super_sticker_metadata:
            _dict['superStickerMetadata'] = self.super_sticker_metadata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of supporter_details
        if self.supporter_details:
            _dict['supporterDetails'] = self.supporter_details.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SuperChatEventSnippet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "amountMicros": obj.get("amountMicros"),
            "channelId": obj.get("channelId"),
            "commentText": obj.get("commentText"),
            "createdAt": obj.get("createdAt"),
            "currency": obj.get("currency"),
            "displayString": obj.get("displayString"),
            "isSuperStickerEvent": obj.get("isSuperStickerEvent"),
            "messageType": obj.get("messageType"),
            "superStickerMetadata": SuperStickerMetadata.from_dict(obj["superStickerMetadata"]) if obj.get("superStickerMetadata") is not None else None,
            "supporterDetails": ChannelProfileDetails.from_dict(obj["supporterDetails"]) if obj.get("supporterDetails") is not None else None
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.live_broadcast_list_response import LiveBroadcastListResponse

class TestLiveBroadcastListResponse(unittest.TestCase):
    """LiveBroadcastListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LiveBroadcastListResponse:
        """Test LiveBroadcastListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LiveBroadcastListResponse`
        """
        model = LiveBroadcastListResponse()
        if include_optional:
            return LiveBroadcastListResponse(
                etag = '',
                event_id = '',
                items = [
                    youtube_ti.models.live_broadcast.LiveBroadcast(
                        content_details = youtube_ti.models.live_broadcast_content_details.LiveBroadcastContentDetails(
                            bound_stream_id = '', 
                            bound_stream_last_update_time_ms = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            closed_captions_type = 'closedCaptionsTypeUnspecified', 
                            enable_auto_start = True, 
                            enable_auto_stop = True, 
                            enable_closed_captions = True, 
                            enable_content_encryption = True, 
                            enable_dvr = True, 
                            enable_embed = True, 
                            enable_low_latency = True, 
                            latency_preference = 'latencyPreferenceUnspecified', 
                            mesh = 'YQ==', 
                            monitor_stream = youtube_ti.models.monitor_stream_info.MonitorStreamInfo(
                                broadcast_stream_delay_ms = 56, 
                                embed_html = '', 
                                enable_monitor_stream = True, ), 
                            projection = 'projectionUnspecified', 
                            record_from_start = True, 
                            start_with_slate = True, 
                            stereo_layout = 'stereoLayoutUnspecified', ), 
                        etag = '', 
                        id = '', 
                        kind = 'youtube#liveBroadcast', 
                        monetization_details = youtube_ti.models.live_broadcast_monetization_details.LiveBroadcastMonetizationDetails(
                            cuepoint_schedule = youtube_ti.models.cuepoint_schedule.CuepointSchedule(
                                enabled = True, 
                                pause_ads_until = '', 
                                repeat_interval_secs = 56, 
                                schedule_strategy = 'scheduleStrategyUnspecified', ), ), 
                        snippet = youtube_ti.models.live_broadcast_snippet.LiveBroadcastSnippet(
                            actual_end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            actual_start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            channel_id = '', 
                            description = '', 
                            is_default_broadcast = True, 
                            live_chat_id = '', 
                            published_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            scheduled_end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            scheduled_start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            thumbnails = youtube_ti.models.thumbnail_details.ThumbnailDetails(
                                default = youtube_ti.models.thumbnail.Thumbnail(
                                    height = 56, 
                                    url = '', 
                                    width = 56, ), 
                                high = youtube_ti.models.thumbnail.Thumbnail(
                                    height = 56, 
                                    url = '', 
                                    width = 56, ), 
                                maxres = , 
                                medium = , 
                                standard = , ), 
                            title = '', ), 
                        statistics = youtube_ti.models.live_broadcast_statistics.LiveBroadcastStatistics(
                            concurrent_viewers = '', ), 
                        status = youtube_ti.models.live_broadcast_status.LiveBroadcastStatus(
                            life_cycle_status = 'lifeCycleStatusUnspecified', 
                            live_broadcast_priority = 'liveBroadcastPriorityUnspecified', 
                            made_for_kids = True, 
                            privacy_status = 'public', 
                            recording_status = 'liveBroadcastRecordingStatusUnspecified', 
                            self_declared_made_for_kids = True, ), )
                    ],
                kind = 'youtube#liveBroadcastListResponse',
                next_page_token = '',
                page_info = youtube_ti.models.page_info.PageInfo(
                    results_per_page = 56, 
                    total_results = 56, ),
                prev_page_token = '',
                token_pagination = None,
                visitor_id = ''
            )
        else:
            return LiveBroadcastListResponse(
        )
        """

    def testLiveBroadcastListResponse(self):
        """Test LiveBroadcastListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.video import Video

class TestVideo(unittest.TestCase):
    """Video unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Video:
        """Test Video
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Video`
        """
        model = Video()
        if include_optional:
            return Video(
                age_gating = youtube_ti.models.video_age_gating.VideoAgeGating(
                    alcohol_content = True, 
                    restricted = True, 
                    video_game_rating = 'anyone', ),
                content_details = youtube_ti.models.video_content_details.VideoContentDetails(
                    caption = 'true', 
                    content_rating = youtube_ti.models.content_rating.ContentRating(
                        acb_rating = 'acbUnspecified', 
                        agcom_rating = 'agcomUnspecified', 
                        anatel_rating = 'anatelUnspecified', 
                        bbfc_rating = 'bbfcUnspecified', 
                        bfvc_rating = 'bfvcUnspecified', 
                        bmukk_rating = 'bmukkUnspecified', 
                        catv_rating = 'catvUnspecified', 
                        catvfr_rating = 'catvfrUnspecified', 
                        cbfc_rating = 'cbfcUnspecified', 
                        ccc_rating = 'cccUnspecified', 
                        cce_rating = 'cceUnspecified', 
                        chfilm_rating = 'chfilmUnspecified', 
                        chvrs_rating = 'chvrsUnspecified', 
                        cicf_rating = 'cicfUnspecified', 
                        cna_rating = 'cnaUnspecified', 
                        cnc_rating = 'cncUnspecified', 
                        csa_rating = 'csaUnspecified', 
                        cscf_rating = 'cscfUnspecified', 
                        czfilm_rating = 'czfilmUnspecified', 
                        djctq_rating = 'djctqUnspecified', 
                        djctq_rating_reasons = [
                            'djctqRatingReasonUnspecified'
                            ], 
                        ecbmct_rating = 'ecbmctUnspecified', 
                        eefilm_rating = 'eefilmUnspecified', 
                        egfilm_rating = 'egfilmUnspecified', 
                        eirin_rating = 'eirinUnspecified', 
                        fcbm_rating = 'fcbmUnspecified', 
                        fco_rating = 'fcoUnspecified', 
                        fmoc_rating = 'fmocUnspecified', 
                        fpb_rating = 'fpbUnspecified', 
                        fpb_rating_reasons = [
                            'fpbRatingReasonUnspecified'
                            ], 
                        fsk_rating = 'fskUnspecified', 
                        grfilm_rating = 'grfilmUnspecified', 
                        icaa_rating = 'icaaUnspecified', 
                        ifco_rating = 'ifcoUnspecified', 
                        ilfilm_rating = 'ilfilmUnspecified', 
                        incaa_rating = 'incaaUnspecified', 
                        kfcb_rating = 'kfcbUnspecified', 
                        kijkwijzer_rating = 'kijkwijzerUnspecified', 
                        kmrb_rating = 'kmrbUnspecified', 
                        lsf_rating = 'lsfUnspecified', 
                        mccaa_rating = 'mccaaUnspecified', 
                        mccyp_rating = 'mccypUnspecified', 
                        mcst_rating = 'mcstUnspecified', 
                        mda_rating = 'mdaUnspecified', 
                        medietilsynet_rating = 'medietilsynetUnspecified', 
                        meku_rating = 'mekuUnspecified', 
                        mena_mpaa_rating = 'menaMpaaUnspecified', 
                        mibac_rating = 'mibacUnspecified', 
                        moc_rating = 'mocUnspecified', 
                        moctw_rating = 'moctwUnspecified', 
                        mpaa_rating = 'mpaaUnspecified', 
                        mpaat_rating = 'mpaatUnspecified', 
                        mtrcb_rating = 'mtrcbUnspecified', 
                        nbc_rating = 'nbcUnspecified', 
                        nbcpl_rating = 'nbcplUnspecified', 
                        nfrc_rating = 'nfrcUnspecified', 
                        nfvcb_rating = 'nfvcbUnspecified', 
                        nkclv_rating = 'nkclvUnspecified', 
                        nmc_rating = 'nmcUnspecified', 
                        oflc_rating = 'oflcUnspecified', 
                        pefilm_rating = 'pefilmUnspecified', 
                        rcnof_rating = 'rcnofUnspecified', 
                        resorteviolencia_rating = 'resorteviolenciaUnspecified', 
                        rtc_rating = 'rtcUnspecified', 
                        rte_rating = 'rteUnspecified', 
                        russia_rating = 'russiaUnspecified', 
                        skfilm_rating = 'skfilmUnspecified', 
                        smais_rating = 'smaisUnspecified', 
                        smsa_rating = 'smsaUnspecified', 
                        tvpg_rating = 'tvpgUnspecified', 
                        yt_rating = 'ytUnspecified', ), 
                    country_restriction = youtube_ti.models.access_policy.AccessPolicy(
                        allowed = True, 
                        exception = [
                            ''
                            ], ), 
                    definition = 'sd', 
                    dimension = '', 
                    duration = '', 
                    has_custom_thumbnail = True, 
                    licensed_content = True, 
                    projection = 'rectangular', 
                    region_restriction = youtube_ti.models.video_content_details_region_restriction.VideoContentDetailsRegionRestriction(
                        allowed = [
                            ''
                            ], 
                        blocked = [
                            ''
                            ], ), ),
                etag = '',
                file_details = youtube_ti.models.video_file_details.VideoFileDetails(
                    audio_streams = [
                        youtube_ti.models.video_file_details_audio_stream.VideoFileDetailsAudioStream(
                            bitrate_bps = '', 
                            channel_count = 56, 
                            codec = '', 
                            vendor = '', )
                        ], 
                    bitrate_bps = '', 
                    container = '', 
                    creation_time = '', 
                    duration_ms = '', 
                    file_name = '', 
                    file_size = '', 
                    file_type = 'video', 
                    video_streams = [
                        youtube_ti.models.video_file_details_video_stream.VideoFileDetailsVideoStream(
                            aspect_ratio = 1.337, 
                            bitrate_bps = '', 
                            codec = '', 
                            frame_rate_fps = 1.337, 
                            height_pixels = 56, 
                            rotation = 'none', 
                            vendor = '', 
                            width_pixels = 56, )
                        ], ),
                id = '',
                kind = 'youtube#video',
                live_streaming_details = youtube_ti.models.video_live_streaming_details.VideoLiveStreamingDetails(
                    active_live_chat_id = '', 
                    actual_end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    actual_start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    concurrent_viewers = '', 
                    scheduled_end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    scheduled_start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                localizations = None,
                monetization_details = youtube_ti.models.video_monetization_details.VideoMonetizationDetails(
                    access = youtube_ti.models.access_policy.AccessPolicy(
                        allowed = True, 
                        exception = [
                            ''
                            ], ), ),
                paid_product_placement_details = youtube_ti.models.video_paid_product_placement_details.VideoPaidProductPlacementDetails(
                    has_paid_product_placement = True, ),
                player = youtube_ti.models.video_player.VideoPlayer(
                    embed_height = '', 
                    embed_html = '', 
                    embed_width = '', ),
                processing_details = youtube_ti.models.video_processing_details.VideoProcessingDetails(
                    editor_suggestions_availability = '', 
                    file_details_availability = '', 
                    processing_failure_reason = 'uploadFailed', 
                    processing_issues_availability = '', 
                    processing_progress = youtube_ti.models.video_processing_details_processing_progress.VideoProcessingDetailsProcessingProgress(
                        parts_processed = '', 
                        parts_total = '', 
                        time_left_ms = '', ), 
                    processing_status = 'processing', 
                    tag_suggestions_availability = '', 
                    thumbnails_availability = '', ),
                project_details = None,
                recording_details = youtube_ti.models.video_recording_details.VideoRecordingDetails(
                    location = youtube_ti.models.geo_point.GeoPoint(
                        altitude = 1.337, 
                        latitude = 1.337, 
                        longitude = 1.337, ), 
                    location_description = '', 
                    recording_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                snippet = youtube_ti.models.video_snippet.VideoSnippet(
                    tags = [
                        ''
                        ], 
                    category_id = '', 
                    channel_id = '', 
                    channel_title = '', 
                    default_audio_language = '', 
                    default_language = '', 
                    description = '', 
                    live_broadcast_content = 'none', 
                    localized = youtube_ti.models.video_localization.VideoLocalization(
                        description = '', 
                        title = '', ), 
                    published_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    thumbnails = youtube_ti.models.thumbnail_details.ThumbnailDetails(
                        default = youtube_ti.models.thumbnail.Thumbnail(
                            height = 56, 
                            url = '', 
                            width = 56, ), 
                        high = youtube_ti.models.thumbnail.Thumbnail(
                            height = 56, 
                            url = '', 
                            width = 56, ), 
                        maxres = , 
                        medium = , 
                        standard = , ), 
                    title = '', ),
                statistics = youtube_ti.models.video_statistics.VideoStatistics(
                    comment_count = '', 
                    dislike_count = '', 
                    favorite_count = '', 
                    like_count = '', 
                    view_count = '', ),
                status = youtube_ti.models.video_status.VideoStatus(
                    contains_synthetic_media = True, 
                    embeddable = True, 
                    failure_reason = 'conversion', 
                    license = 'youtube', 
                    made_for_kids = True, 
                    privacy_status = 'public', 
                    public_stats_viewable = True, 
                    publish_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    rejection_reason = 'copyright', 
                    self_declared_made_for_kids = True, 
                    upload_status = 'uploaded', ),
                suggestions = youtube_ti.models.video_suggestions.VideoSuggestions(
                    editor_suggestions = [
                        'videoAutoLevels'
                        ], 
                    processing_errors = [
                        'audioFile'
                        ], 
                    processing_hints = [
                        'nonStreamableMov'
                        ], 
                    processing_warnings = [
                        'unknownContainer'
                        ], 
                    tag_suggestions = [
                        youtube_ti.models.video_suggestions_tag_suggestion.VideoSuggestionsTagSuggestion(
                            category_restricts = [
                                ''
                                ], 
                            tag = '', )
                        ], ),
                topic_details = youtube_ti.models.video_topic_details.VideoTopicDetails(
                    relevant_topic_ids = [
                        ''
                        ], 
                    topic_categories = [
                        ''
                        ], 
                    topic_ids = [
                        ''
                        ], )
            )
        else:
            return Video(
        )
        """

    def testVideo(self):
        """Test Video"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class IngestionInfo(BaseModel):
    """
    Describes information necessary for ingesting an RTMP, HTTP, or SRT stream.
    """ # noqa: E501
    backup_ingestion_address: Optional[StrictStr] = Field(default=None, description="The backup ingestion URL that you should use to stream video to YouTube. You have the option of simultaneously streaming the content that you are sending to the ingestionAddress to this URL.", alias="backupIngestionAddress")
    ingestion_address: Optional[StrictStr] = Field(default=None, description="The primary ingestion URL that you should use to stream video to YouTube. You must stream video to this URL. Depending on which application or tool you use to encode your video stream, you may need to enter the stream URL and stream name separately or you may need to concatenate them in the following format: *STREAM_URL/STREAM_NAME* ", alias="ingestionAddress")
    rtmps_backup_ingestion_address: Optional[StrictStr] = Field(default=None, description="This ingestion url may be used instead of backupIngestionAddress in order to stream via RTMPS. Not applicable to non-RTMP streams.", alias="rtmpsBackupIngestionAddress")
    rtmps_ingestion_address: Optional[StrictStr] = Field(default=None, description="This ingestion url may be used instead of ingestionAddress in order to stream via RTMPS. Not applicable to non-RTMP streams.", alias="rtmpsIngestionAddress")
    stream_name: Optional[StrictStr] = Field(default=None, description="The stream name that YouTube assigns to the video stream.", alias="streamName")
    __properties: ClassVar[List[str]] = ["backupIngestionAddress", "ingestionAddress", "rtmpsBackupIngestionAddress", "rtmpsIngestionAddress", "streamName"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of IngestionInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of IngestionInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "backupIngestionAddress": obj.get("backupIngestionAddress"),
            "ingestionAddress": obj.get("ingestionAddress"),
            "rtmpsBackupIngestionAddress": obj.get("rtmpsBackupIngestionAddress"),
            "rtmpsIngestionAddress": obj.get("rtmpsIngestionAddress"),
            "streamName": obj.get("streamName")
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.channel_section_snippet import ChannelSectionSnippet

class TestChannelSectionSnippet(unittest.TestCase):
    """ChannelSectionSnippet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChannelSectionSnippet:
        """Test ChannelSectionSnippet
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChannelSectionSnippet`
        """
        model = ChannelSectionSnippet()
        if include_optional:
            return ChannelSectionSnippet(
                channel_id = '',
                default_language = '',
                localized = youtube_ti.models.channel_section_localization.ChannelSectionLocalization(
                    title = '', ),
                position = 56,
                style = 'channelsectionStyleUnspecified',
                title = '',
                type = 'channelsectionTypeUndefined'
            )
        else:
            return ChannelSectionSnippet(
        )
        """

    def testChannelSectionSnippet(self):
        """Test ChannelSectionSnippet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.channel_branding_settings import ChannelBrandingSettings

class TestChannelBrandingSettings(unittest.TestCase):
    """ChannelBrandingSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChannelBrandingSettings:
        """Test ChannelBrandingSettings
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChannelBrandingSettings`
        """
        model = ChannelBrandingSettings()
        if include_optional:
            return ChannelBrandingSettings(
                channel = youtube_ti.models.channel_settings.ChannelSettings(
                    country = '', 
                    default_language = '', 
                    default_tab = '', 
                    description = '', 
                    featured_channels_title = '', 
                    featured_channels_urls = [
                        ''
                        ], 
                    keywords = '', 
                    moderate_comments = True, 
                    profile_color = '', 
                    show_browse_view = True, 
                    show_related_channels = True, 
                    title = '', 
                    tracking_analytics_account_id = '', 
                    unsubscribed_trailer = '', ),
                hints = [
                    youtube_ti.models.property_value.PropertyValue(
                        property = '', 
                        value = '', )
                    ],
                image = youtube_ti.models.image_settings.ImageSettings(
                    background_image_url = youtube_ti.models.localized_property.LocalizedProperty(
                        default = '', 
                        default_language = youtube_ti.models.language_tag.LanguageTag(
                            value = '', ), 
                        localized = [
                            youtube_ti.models.localized_string.LocalizedString(
                                language = '', 
                                value = '', )
                            ], ), 
                    banner_external_url = '', 
                    banner_image_url = '', 
                    banner_mobile_extra_hd_image_url = '', 
                    banner_mobile_hd_image_url = '', 
                    banner_mobile_image_url = '', 
                    banner_mobile_low_image_url = '', 
                    banner_mobile_medium_hd_image_url = '', 
                    banner_tablet_extra_hd_image_url = '', 
                    banner_tablet_hd_image_url = '', 
                    banner_tablet_image_url = '', 
                    banner_tablet_low_image_url = '', 
                    banner_tv_high_image_url = '', 
                    banner_tv_image_url = '', 
                    banner_tv_low_image_url = '', 
                    banner_tv_medium_image_url = '', 
                    large_branded_banner_image_imap_script = youtube_ti.models.localized_property.LocalizedProperty(
                        default = '', ), 
                    large_branded_banner_image_url = , 
                    small_branded_banner_image_imap_script = , 
                    small_branded_banner_image_url = , 
                    tracking_image_url = '', 
                    watch_icon_image_url = '', ),
                watch = youtube_ti.models.watch_settings.WatchSettings(
                    background_color = '', 
                    featured_playlist_id = '', 
                    text_color = '', )
            )
        else:
            return ChannelBrandingSettings(
        )
        """

    def testChannelBrandingSettings(self):
        """Test ChannelBrandingSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from youtube_ti.models.video_file_details_audio_stream import VideoFileDetailsAudioStream
from youtube_ti.models.video_file_details_video_stream import VideoFileDetailsVideoStream
from typing import Optional, Set
from typing_extensions import Self

class VideoFileDetails(BaseModel):
    """
    Describes original video file properties, including technical details about audio and video streams, but also metadata information like content length, digitization time, or geotagging information.
    """ # noqa: E501
    audio_streams: Optional[List[VideoFileDetailsAudioStream]] = Field(default=None, description="A list of audio streams contained in the uploaded video file. Each item in the list contains detailed metadata about an audio stream.", alias="audioStreams")
    bitrate_bps: Optional[StrictStr] = Field(default=None, description="The uploaded video file's combined (video and audio) bitrate in bits per second.", alias="bitrateBps")
    container: Optional[StrictStr] = Field(default=None, description="The uploaded video file's container format.")
    creation_time: Optional[StrictStr] = Field(default=None, description="The date and time when the uploaded video file was created. The value is specified in ISO 8601 format. Currently, the following ISO 8601 formats are supported: - Date only: YYYY-MM-DD - Naive time: YYYY-MM-DDTHH:MM:SS - Time with timezone: YYYY-MM-DDTHH:MM:SS+HH:MM ", alias="creationTime")
    duration_ms: Optional[StrictStr] = Field(default=None, description="The length of the uploaded video in milliseconds.", alias="durationMs")
    file_name: Optional[StrictStr] = Field(default=None, description="The uploaded file's name. This field is present whether a video file or another type of file was uploaded.", alias="fileName")
    file_size: Optional[StrictStr] = Field(default=None, description="The uploaded file's size in bytes. This field is present whether a video file or another type of file was uploaded.", alias="fileSize")
    file_type: Optional[StrictStr] = Field(default=None, description="The uploaded file's type as detected by YouTube's video processing engine. Currently, YouTube only processes video files, but this field is present whether a video file or another type of file was uploaded.", alias="fileType")
    video_streams: Optional[List[VideoFileDetailsVideoStream]] = Field(default=None, description="A list of video streams contained in the uploaded video file. Each item in the list contains detailed metadata about a video stream.", alias="videoStreams")
    __properties: ClassVar[List[str]] = ["audioStreams", "bitrateBps", "container", "creationTime", "durationMs", "fileName", "fileSize", "fileType", "videoStreams"]

    @field_validator('file_type')
    def file_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['video', 'audio', 'image', 'archive', 'document', 'project', 'other']):
            raise ValueError("must be one of enum values ('video', 'audio', 'image', 'archive', 'document', 'project', 'other')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VideoFileDetails from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in audio_streams (list)
        _items = []
        if self.audio_streams:
            for _item_audio_streams in self.audio_streams:
                if _item_audio_streams:
                    _items.append(_item_audio_streams.to_dict())
            _dict['audioStreams'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in video_streams (list)
        _items = []
        if self.video_streams:
            for _item_video_streams in self.video_streams:
                if _item_video_streams:
                    _items.append(_item_video_streams.to_dict())
            _dict['videoStreams'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VideoFileDetails from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "audioStreams": [VideoFileDetailsAudioStream.from_dict(_item) for _item in obj["audioStreams"]] if obj.get("audioStreams") is not None else None,
            "bitrateBps": obj.get("bitrateBps"),
            "container": obj.get("container"),
            "creationTime": obj.get("creationTime"),
            "durationMs": obj.get("durationMs"),
            "fileName": obj.get("fileName"),
            "fileSize": obj.get("fileSize"),
            "fileType": obj.get("fileType"),
            "videoStreams": [VideoFileDetailsVideoStream.from_dict(_item) for _item in obj["videoStreams"]] if obj.get("videoStreams") is not None else None
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.live_chat_poll_details import LiveChatPollDetails

class TestLiveChatPollDetails(unittest.TestCase):
    """LiveChatPollDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LiveChatPollDetails:
        """Test LiveChatPollDetails
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LiveChatPollDetails`
        """
        model = LiveChatPollDetails()
        if include_optional:
            return LiveChatPollDetails(
                metadata = youtube_ti.models.live_chat_poll_details_poll_metadata.LiveChatPollDetailsPollMetadata(
                    options = [
                        youtube_ti.models.live_chat_poll_details_poll_metadata_poll_option.LiveChatPollDetailsPollMetadataPollOption(
                            option_text = '', 
                            tally = '', )
                        ], 
                    question_text = '', ),
                status = 'unknown'
            )
        else:
            return LiveChatPollDetails(
        )
        """

    def testLiveChatPollDetails(self):
        """Test LiveChatPollDetails"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from youtube_ti.models.abuse_report import AbuseReport
from youtube_ti.models.abuse_type import AbuseType
from youtube_ti.models.access_policy import AccessPolicy
from youtube_ti.models.activity import Activity
from youtube_ti.models.activity_content_details import ActivityContentDetails
from youtube_ti.models.activity_content_details_bulletin import ActivityContentDetailsBulletin
from youtube_ti.models.activity_content_details_channel_item import ActivityContentDetailsChannelItem
from youtube_ti.models.activity_content_details_comment import ActivityContentDetailsComment
from youtube_ti.models.activity_content_details_favorite import ActivityContentDetailsFavorite
from youtube_ti.models.activity_content_details_like import ActivityContentDetailsLike
from youtube_ti.models.activity_content_details_playlist_item import ActivityContentDetailsPlaylistItem
from youtube_ti.models.activity_content_details_promoted_item import ActivityContentDetailsPromotedItem
from youtube_ti.models.activity_content_details_recommendation import ActivityContentDetailsRecommendation
from youtube_ti.models.activity_content_details_social import ActivityContentDetailsSocial
from youtube_ti.models.activity_content_details_subscription import ActivityContentDetailsSubscription
from youtube_ti.models.activity_content_details_upload import ActivityContentDetailsUpload
from youtube_ti.models.activity_list_response import ActivityListResponse
from youtube_ti.models.activity_snippet import ActivitySnippet
from youtube_ti.models.caption import Caption
from youtube_ti.models.caption_list_response import CaptionListResponse
from youtube_ti.models.caption_snippet import CaptionSnippet
from youtube_ti.models.cdn_settings import CdnSettings
from youtube_ti.models.channel import Channel
from youtube_ti.models.channel_audit_details import ChannelAuditDetails
from youtube_ti.models.channel_banner_resource import ChannelBannerResource
from youtube_ti.models.channel_branding_settings import ChannelBrandingSettings
from youtube_ti.models.channel_content_details import ChannelContentDetails
from youtube_ti.models.channel_content_details_related_playlists import ChannelContentDetailsRelatedPlaylists
from youtube_ti.models.channel_content_owner_details import ChannelContentOwnerDetails
from youtube_ti.models.channel_conversion_ping import ChannelConversionPing
from youtube_ti.models.channel_conversion_pings import ChannelConversionPings
from youtube_ti.models.channel_list_response import ChannelListResponse
from youtube_ti.models.channel_localization import ChannelLocalization
from youtube_ti.models.channel_profile_details import ChannelProfileDetails
from youtube_ti.models.channel_section import ChannelSection
from youtube_ti.models.channel_section_content_details import ChannelSectionContentDetails
from youtube_ti.models.channel_section_list_response import ChannelSectionListResponse
from youtube_ti.models.channel_section_localization import ChannelSectionLocalization
from youtube_ti.models.channel_section_snippet import ChannelSectionSnippet
from youtube_ti.models.channel_section_targeting import ChannelSectionTargeting
from youtube_ti.models.channel_settings import ChannelSettings
from youtube_ti.models.channel_snippet import ChannelSnippet
from youtube_ti.models.channel_statistics import ChannelStatistics
from youtube_ti.models.channel_status import ChannelStatus
from youtube_ti.models.channel_to_store_link_details import ChannelToStoreLinkDetails
from youtube_ti.models.channel_to_store_link_details_billing_details import ChannelToStoreLinkDetailsBillingDetails
from youtube_ti.models.channel_to_store_link_details_merchant_affiliate_program_details import ChannelToStoreLinkDetailsMerchantAffiliateProgramDetails
from youtube_ti.models.channel_topic_details import ChannelTopicDetails
from youtube_ti.models.comment import Comment
from youtube_ti.models.comment_list_response import CommentListResponse
from youtube_ti.models.comment_snippet import CommentSnippet
from youtube_ti.models.comment_snippet_author_channel_id import CommentSnippetAuthorChannelId
from youtube_ti.models.comment_thread import CommentThread
from youtube_ti.models.comment_thread_list_response import CommentThreadListResponse
from youtube_ti.models.comment_thread_replies import CommentThreadReplies
from youtube_ti.models.comment_thread_snippet import CommentThreadSnippet
from youtube_ti.models.content_rating import ContentRating
from youtube_ti.models.cuepoint import Cuepoint
from youtube_ti.models.cuepoint_schedule import CuepointSchedule
from youtube_ti.models.entity import Entity
from youtube_ti.models.geo_point import GeoPoint
from youtube_ti.models.i18n_language import I18nLanguage
from youtube_ti.models.i18n_language_list_response import I18nLanguageListResponse
from youtube_ti.models.i18n_language_snippet import I18nLanguageSnippet
from youtube_ti.models.i18n_region import I18nRegion
from youtube_ti.models.i18n_region_list_response import I18nRegionListResponse
from youtube_ti.models.i18n_region_snippet import I18nRegionSnippet
from youtube_ti.models.image_settings import ImageSettings
from youtube_ti.models.ingestion_info import IngestionInfo
from youtube_ti.models.invideo_branding import InvideoBranding
from youtube_ti.models.invideo_position import InvideoPosition
from youtube_ti.models.invideo_timing import InvideoTiming
from youtube_ti.models.language_tag import LanguageTag
from youtube_ti.models.level_details import LevelDetails
from youtube_ti.models.live_broadcast import LiveBroadcast
from youtube_ti.models.live_broadcast_content_details import LiveBroadcastContentDetails
from youtube_ti.models.live_broadcast_list_response import LiveBroadcastListResponse
from youtube_ti.models.live_broadcast_monetization_details import LiveBroadcastMonetizationDetails
from youtube_ti.models.live_broadcast_snippet import LiveBroadcastSnippet
from youtube_ti.models.live_broadcast_statistics import LiveBroadcastStatistics
from youtube_ti.models.live_broadcast_status import LiveBroadcastStatus
from youtube_ti.models.live_chat_ban import LiveChatBan
from youtube_ti.models.live_chat_ban_snippet import LiveChatBanSnippet
from youtube_ti.models.live_chat_fan_funding_event_details import LiveChatFanFundingEventDetails
from youtube_ti.models.live_chat_gift_membership_received_details import LiveChatGiftMembershipReceivedDetails
from youtube_ti.models.live_chat_member_milestone_chat_details import LiveChatMemberMilestoneChatDetails
from youtube_ti.models.live_chat_membership_gifting_details import LiveChatMembershipGiftingDetails
from youtube_ti.models.live_chat_message import LiveChatMessage
from youtube_ti.models.live_chat_message_author_details import LiveChatMessageAuthorDetails
from youtube_ti.models.live_chat_message_deleted_details import LiveChatMessageDeletedDetails
from youtube_ti.models.live_chat_message_list_response import LiveChatMessageListResponse
from youtube_ti.models.live_chat_message_retracted_details import LiveChatMessageRetractedDetails
from youtube_ti.models.live_chat_message_snippet import LiveChatMessageSnippet
from youtube_ti.models.live_chat_moderator import LiveChatModerator
from youtube_ti.models.live_chat_moderator_list_response import LiveChatModeratorListResponse
from youtube_ti.models.live_chat_moderator_snippet import LiveChatModeratorSnippet
from youtube_ti.models.live_chat_new_sponsor_details import LiveChatNewSponsorDetails
from youtube_ti.models.live_chat_poll_details import LiveChatPollDetails
from youtube_ti.models.live_chat_poll_details_poll_metadata import LiveChatPollDetailsPollMetadata
from youtube_ti.models.live_chat_poll_details_poll_metadata_poll_option import LiveChatPollDetailsPollMetadataPollOption
from youtube_ti.models.live_chat_super_chat_details import LiveChatSuperChatDetails
from youtube_ti.models.live_chat_super_sticker_details import LiveChatSuperStickerDetails
from youtube_ti.models.live_chat_text_message_details import LiveChatTextMessageDetails
from youtube_ti.models.live_chat_user_banned_message_details import LiveChatUserBannedMessageDetails
from youtube_ti.models.live_stream import LiveStream
from youtube_ti.models.live_stream_configuration_issue import LiveStreamConfigurationIssue
from youtube_ti.models.live_stream_content_details import LiveStreamContentDetails
from youtube_ti.models.live_stream_health_status import LiveStreamHealthStatus
from youtube_ti.models.live_stream_list_response import LiveStreamListResponse
from youtube_ti.models.live_stream_snippet import LiveStreamSnippet
from youtube_ti.models.live_stream_status import LiveStreamStatus
from youtube_ti.models.localized_property import LocalizedProperty
from youtube_ti.models.localized_string import LocalizedString
from youtube_ti.models.member import Member
from youtube_ti.models.member_list_response import MemberListResponse
from youtube_ti.models.member_snippet import MemberSnippet
from youtube_ti.models.memberships_details import MembershipsDetails
from youtube_ti.models.memberships_duration import MembershipsDuration
from youtube_ti.models.memberships_duration_at_level import MembershipsDurationAtLevel
from youtube_ti.models.memberships_level import MembershipsLevel
from youtube_ti.models.memberships_level_list_response import MembershipsLevelListResponse
from youtube_ti.models.memberships_level_snippet import MembershipsLevelSnippet
from youtube_ti.models.monitor_stream_info import MonitorStreamInfo
from youtube_ti.models.page_info import PageInfo
from youtube_ti.models.playlist import Playlist
from youtube_ti.models.playlist_content_details import PlaylistContentDetails
from youtube_ti.models.playlist_image import PlaylistImage
from youtube_ti.models.playlist_image_list_response import PlaylistImageListResponse
from youtube_ti.models.playlist_image_snippet import PlaylistImageSnippet
from youtube_ti.models.playlist_item import PlaylistItem
from youtube_ti.models.playlist_item_content_details import PlaylistItemContentDetails
from youtube_ti.models.playlist_item_list_response import PlaylistItemListResponse
from youtube_ti.models.playlist_item_snippet import PlaylistItemSnippet
from youtube_ti.models.playlist_item_status import PlaylistItemStatus
from youtube_ti.models.playlist_list_response import PlaylistListResponse
from youtube_ti.models.playlist_localization import PlaylistLocalization
from youtube_ti.models.playlist_player import PlaylistPlayer
from youtube_ti.models.playlist_snippet import PlaylistSnippet
from youtube_ti.models.playlist_status import PlaylistStatus
from youtube_ti.models.property_value import PropertyValue
from youtube_ti.models.related_entity import RelatedEntity
from youtube_ti.models.resource_id import ResourceId
from youtube_ti.models.search_list_response import SearchListResponse
from youtube_ti.models.search_result import SearchResult
from youtube_ti.models.search_result_snippet import SearchResultSnippet
from youtube_ti.models.subscription import Subscription
from youtube_ti.models.subscription_content_details import SubscriptionContentDetails
from youtube_ti.models.subscription_list_response import SubscriptionListResponse
from youtube_ti.models.subscription_snippet import SubscriptionSnippet
from youtube_ti.models.subscription_subscriber_snippet import SubscriptionSubscriberSnippet
from youtube_ti.models.super_chat_event import SuperChatEvent
from youtube_ti.models.super_chat_event_list_response import SuperChatEventListResponse
from youtube_ti.models.super_chat_event_snippet import SuperChatEventSnippet
from youtube_ti.models.super_sticker_metadata import SuperStickerMetadata
from youtube_ti.models.test_item import TestItem
from youtube_ti.models.third_party_link import ThirdPartyLink
from youtube_ti.models.third_party_link_list_response import ThirdPartyLinkListResponse
from youtube_ti.models.third_party_link_snippet import ThirdPartyLinkSnippet
from youtube_ti.models.third_party_link_status import ThirdPartyLinkStatus
from youtube_ti.models.thumbnail import Thumbnail
from youtube_ti.models.thumbnail_details import ThumbnailDetails
from youtube_ti.models.thumbnail_set_response import ThumbnailSetResponse
from youtube_ti.models.video import Video
from youtube_ti.models.video_abuse_report import VideoAbuseReport
from youtube_ti.models.video_abuse_report_reason import VideoAbuseReportReason
from youtube_ti.models.video_abuse_report_reason_list_response import VideoAbuseReportReasonListResponse
from youtube_ti.models.video_abuse_report_reason_snippet import VideoAbuseReportReasonSnippet
from youtube_ti.models.video_abuse_report_secondary_reason import VideoAbuseReportSecondaryReason
from youtube_ti.models.video_age_gating import VideoAgeGating
from youtube_ti.models.video_category import VideoCategory
from youtube_ti.models.video_category_list_response import VideoCategoryListResponse
from youtube_ti.models.video_category_snippet import VideoCategorySnippet
from youtube_ti.models.video_content_details import VideoContentDetails
from youtube_ti.models.video_content_details_region_restriction import VideoContentDetailsRegionRestriction
from youtube_ti.models.video_file_details import VideoFileDetails
from youtube_ti.models.video_file_details_audio_stream import VideoFileDetailsAudioStream
from youtube_ti.models.video_file_details_video_stream import VideoFileDetailsVideoStream
from youtube_ti.models.video_get_rating_response import VideoGetRatingResponse
from youtube_ti.models.video_list_response import VideoListResponse
from youtube_ti.models.video_live_streaming_details import VideoLiveStreamingDetails
from youtube_ti.models.video_localization import VideoLocalization
from youtube_ti.models.video_monetization_details import VideoMonetizationDetails
from youtube_ti.models.video_paid_product_placement_details import VideoPaidProductPlacementDetails
from youtube_ti.models.video_player import VideoPlayer
from youtube_ti.models.video_processing_details import VideoProcessingDetails
from youtube_ti.models.video_processing_details_processing_progress import VideoProcessingDetailsProcessingProgress
from youtube_ti.models.video_rating import VideoRating
from youtube_ti.models.video_recording_details import VideoRecordingDetails
from youtube_ti.models.video_snippet import VideoSnippet
from youtube_ti.models.video_statistics import VideoStatistics
from youtube_ti.models.video_status import VideoStatus
from youtube_ti.models.video_suggestions import VideoSuggestions
from youtube_ti.models.video_suggestions_tag_suggestion import VideoSuggestionsTagSuggestion
from youtube_ti.models.video_topic_details import VideoTopicDetails
from youtube_ti.models.video_trainability import VideoTrainability
from youtube_ti.models.watch_settings import WatchSettings



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from youtube_ti.models.playlist_item_content_details import PlaylistItemContentDetails
from youtube_ti.models.playlist_item_snippet import PlaylistItemSnippet
from youtube_ti.models.playlist_item_status import PlaylistItemStatus
from typing import Optional, Set
from typing_extensions import Self

class PlaylistItem(BaseModel):
    """
    A *playlistItem* resource identifies another resource, such as a video, that is included in a playlist. In addition, the playlistItem resource contains details about the included resource that pertain specifically to how that resource is used in that playlist. YouTube uses playlists to identify special collections of videos for a channel, such as: - uploaded videos - favorite videos - positively rated (liked) videos - watch history - watch later To be more specific, these lists are associated with a channel, which is a collection of a person, group, or company's videos, playlists, and other YouTube information. You can retrieve the playlist IDs for each of these lists from the channel resource for a given channel. You can then use the playlistItems.list method to retrieve any of those lists. You can also add or remove items from those lists by calling the playlistItems.insert and playlistItems.delete methods. For example, if a user gives a positive rating to a video, you would insert that video into the liked videos playlist for that user's channel.
    """ # noqa: E501
    content_details: Optional[PlaylistItemContentDetails] = Field(default=None, alias="contentDetails")
    etag: Optional[StrictStr] = Field(default=None, description="Etag of this resource.")
    id: Optional[StrictStr] = Field(default=None, description="The ID that YouTube uses to uniquely identify the playlist item.")
    kind: Optional[StrictStr] = Field(default='youtube#playlistItem', description="Identifies what kind of resource this is. Value: the fixed string \"youtube#playlistItem\".")
    snippet: Optional[PlaylistItemSnippet] = None
    status: Optional[PlaylistItemStatus] = None
    __properties: ClassVar[List[str]] = ["contentDetails", "etag", "id", "kind", "snippet", "status"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PlaylistItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of content_details
        if self.content_details:
            _dict['contentDetails'] = self.content_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of snippet
        if self.snippet:
            _dict['snippet'] = self.snippet.to_dict()
        # override the default output from pydantic by calling `to_dict()` of status
        if self.status:
            _dict['status'] = self.status.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PlaylistItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "contentDetails": PlaylistItemContentDetails.from_dict(obj["contentDetails"]) if obj.get("contentDetails") is not None else None,
            "etag": obj.get("etag"),
            "id": obj.get("id"),
            "kind": obj.get("kind") if obj.get("kind") is not None else 'youtube#playlistItem',
            "snippet": PlaylistItemSnippet.from_dict(obj["snippet"]) if obj.get("snippet") is not None else None,
            "status": PlaylistItemStatus.from_dict(obj["status"]) if obj.get("status") is not None else None
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.live_chat_ban import LiveChatBan

class TestLiveChatBan(unittest.TestCase):
    """LiveChatBan unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LiveChatBan:
        """Test LiveChatBan
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LiveChatBan`
        """
        model = LiveChatBan()
        if include_optional:
            return LiveChatBan(
                etag = '',
                id = '',
                kind = 'youtube#liveChatBan',
                snippet = youtube_ti.models.live_chat_ban_snippet.LiveChatBanSnippet(
                    ban_duration_seconds = '', 
                    banned_user_details = youtube_ti.models.channel_profile_details.ChannelProfileDetails(
                        channel_id = '', 
                        channel_url = '', 
                        display_name = '', 
                        profile_image_url = '', ), 
                    live_chat_id = '', 
                    type = 'liveChatBanTypeUnspecified', )
            )
        else:
            return LiveChatBan(
        )
        """

    def testLiveChatBan(self):
        """Test LiveChatBan"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.channel_section_list_response import ChannelSectionListResponse

class TestChannelSectionListResponse(unittest.TestCase):
    """ChannelSectionListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChannelSectionListResponse:
        """Test ChannelSectionListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChannelSectionListResponse`
        """
        model = ChannelSectionListResponse()
        if include_optional:
            return ChannelSectionListResponse(
                etag = '',
                event_id = '',
                items = [
                    youtube_ti.models.channel_section.ChannelSection(
                        content_details = youtube_ti.models.channel_section_content_details.ChannelSectionContentDetails(
                            channels = [
                                ''
                                ], 
                            playlists = [
                                ''
                                ], ), 
                        etag = '', 
                        id = '', 
                        kind = 'youtube#channelSection', 
                        localizations = youtube_ti.models.localizations.localizations(), 
                        snippet = youtube_ti.models.channel_section_snippet.ChannelSectionSnippet(
                            channel_id = '', 
                            default_language = '', 
                            localized = youtube_ti.models.channel_section_localization.ChannelSectionLocalization(
                                title = '', ), 
                            position = 56, 
                            style = 'channelsectionStyleUnspecified', 
                            title = '', 
                            type = 'channelsectionTypeUndefined', ), 
                        targeting = youtube_ti.models.channel_section_targeting.ChannelSectionTargeting(
                            countries = [
                                ''
                                ], 
                            languages = [
                                ''
                                ], 
                            regions = [
                                ''
                                ], ), )
                    ],
                kind = 'youtube#channelSectionListResponse',
                visitor_id = ''
            )
        else:
            return ChannelSectionListResponse(
        )
        """

    def testChannelSectionListResponse(self):
        """Test ChannelSectionListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from youtube_ti.models.localized_property import LocalizedProperty
from typing import Optional, Set
from typing_extensions import Self

class ImageSettings(BaseModel):
    """
    Branding properties for images associated with the channel.
    """ # noqa: E501
    background_image_url: Optional[LocalizedProperty] = Field(default=None, alias="backgroundImageUrl")
    banner_external_url: Optional[StrictStr] = Field(default=None, description="This is generated when a ChannelBanner.Insert request has succeeded for the given channel.", alias="bannerExternalUrl")
    banner_image_url: Optional[StrictStr] = Field(default=None, description="Banner image. Desktop size (1060x175).", alias="bannerImageUrl")
    banner_mobile_extra_hd_image_url: Optional[StrictStr] = Field(default=None, description="Banner image. Mobile size high resolution (1440x395).", alias="bannerMobileExtraHdImageUrl")
    banner_mobile_hd_image_url: Optional[StrictStr] = Field(default=None, description="Banner image. Mobile size high resolution (1280x360).", alias="bannerMobileHdImageUrl")
    banner_mobile_image_url: Optional[StrictStr] = Field(default=None, description="Banner image. Mobile size (640x175).", alias="bannerMobileImageUrl")
    banner_mobile_low_image_url: Optional[StrictStr] = Field(default=None, description="Banner image. Mobile size low resolution (320x88).", alias="bannerMobileLowImageUrl")
    banner_mobile_medium_hd_image_url: Optional[StrictStr] = Field(default=None, description="Banner image. Mobile size medium/high resolution (960x263).", alias="bannerMobileMediumHdImageUrl")
    banner_tablet_extra_hd_image_url: Optional[StrictStr] = Field(default=None, description="Banner image. Tablet size extra high resolution (2560x424).", alias="bannerTabletExtraHdImageUrl")
    banner_tablet_hd_image_url: Optional[StrictStr] = Field(default=None, description="Banner image. Tablet size high resolution (2276x377).", alias="bannerTabletHdImageUrl")
    banner_tablet_image_url: Optional[StrictStr] = Field(default=None, description="Banner image. Tablet size (1707x283).", alias="bannerTabletImageUrl")
    banner_tablet_low_image_url: Optional[StrictStr] = Field(default=None, description="Banner image. Tablet size low resolution (1138x188).", alias="bannerTabletLowImageUrl")
    banner_tv_high_image_url: Optional[StrictStr] = Field(default=None, description="Banner image. TV size high resolution (1920x1080).", alias="bannerTvHighImageUrl")
    banner_tv_image_url: Optional[StrictStr] = Field(default=None, description="Banner image. TV size extra high resolution (2120x1192).", alias="bannerTvImageUrl")
    banner_tv_low_image_url: Optional[StrictStr] = Field(default=None, description="Banner image. TV size low resolution (854x480).", alias="bannerTvLowImageUrl")
    banner_tv_medium_image_url: Optional[StrictStr] = Field(default=None, description="Banner image. TV size medium resolution (1280x720).", alias="bannerTvMediumImageUrl")
    large_branded_banner_image_imap_script: Optional[LocalizedProperty] = Field(default=None, alias="largeBrandedBannerImageImapScript")
    large_branded_banner_image_url: Optional[LocalizedProperty] = Field(default=None, alias="largeBrandedBannerImageUrl")
    small_branded_banner_image_imap_script: Optional[LocalizedProperty] = Field(default=None, alias="smallBrandedBannerImageImapScript")
    small_branded_banner_image_url: Optional[LocalizedProperty] = Field(default=None, alias="smallBrandedBannerImageUrl")
    tracking_image_url: Optional[StrictStr] = Field(default=None, description="The URL for a 1px by 1px tracking pixel that can be used to collect statistics for views of the channel or video pages.", alias="trackingImageUrl")
    watch_icon_image_url: Optional[StrictStr] = Field(default=None, alias="watchIconImageUrl")
    __properties: ClassVar[List[str]] = ["backgroundImageUrl", "bannerExternalUrl", "bannerImageUrl", "bannerMobileExtraHdImageUrl", "bannerMobileHdImageUrl", "bannerMobileImageUrl", "bannerMobileLowImageUrl", "bannerMobileMediumHdImageUrl", "bannerTabletExtraHdImageUrl", "bannerTabletHdImageUrl", "bannerTabletImageUrl", "bannerTabletLowImageUrl", "bannerTvHighImageUrl", "bannerTvImageUrl", "bannerTvLowImageUrl", "bannerTvMediumImageUrl", "largeBrandedBannerImageImapScript", "largeBrandedBannerImageUrl", "smallBrandedBannerImageImapScript", "smallBrandedBannerImageUrl", "trackingImageUrl", "watchIconImageUrl"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ImageSettings from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of background_image_url
        if self.background_image_url:
            _dict['backgroundImageUrl'] = self.background_image_url.to_dict()
        # override the default output from pydantic by calling `to_dict()` of large_branded_banner_image_imap_script
        if self.large_branded_banner_image_imap_script:
            _dict['largeBrandedBannerImageImapScript'] = self.large_branded_banner_image_imap_script.to_dict()
        # override the default output from pydantic by calling `to_dict()` of large_branded_banner_image_url
        if self.large_branded_banner_image_url:
            _dict['largeBrandedBannerImageUrl'] = self.large_branded_banner_image_url.to_dict()
        # override the default output from pydantic by calling `to_dict()` of small_branded_banner_image_imap_script
        if self.small_branded_banner_image_imap_script:
            _dict['smallBrandedBannerImageImapScript'] = self.small_branded_banner_image_imap_script.to_dict()
        # override the default output from pydantic by calling `to_dict()` of small_branded_banner_image_url
        if self.small_branded_banner_image_url:
            _dict['smallBrandedBannerImageUrl'] = self.small_branded_banner_image_url.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ImageSettings from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "backgroundImageUrl": LocalizedProperty.from_dict(obj["backgroundImageUrl"]) if obj.get("backgroundImageUrl") is not None else None,
            "bannerExternalUrl": obj.get("bannerExternalUrl"),
            "bannerImageUrl": obj.get("bannerImageUrl"),
            "bannerMobileExtraHdImageUrl": obj.get("bannerMobileExtraHdImageUrl"),
            "bannerMobileHdImageUrl": obj.get("bannerMobileHdImageUrl"),
            "bannerMobileImageUrl": obj.get("bannerMobileImageUrl"),
            "bannerMobileLowImageUrl": obj.get("bannerMobileLowImageUrl"),
            "bannerMobileMediumHdImageUrl": obj.get("bannerMobileMediumHdImageUrl"),
            "bannerTabletExtraHdImageUrl": obj.get("bannerTabletExtraHdImageUrl"),
            "bannerTabletHdImageUrl": obj.get("bannerTabletHdImageUrl"),
            "bannerTabletImageUrl": obj.get("bannerTabletImageUrl"),
            "bannerTabletLowImageUrl": obj.get("bannerTabletLowImageUrl"),
            "bannerTvHighImageUrl": obj.get("bannerTvHighImageUrl"),
            "bannerTvImageUrl": obj.get("bannerTvImageUrl"),
            "bannerTvLowImageUrl": obj.get("bannerTvLowImageUrl"),
            "bannerTvMediumImageUrl": obj.get("bannerTvMediumImageUrl"),
            "largeBrandedBannerImageImapScript": LocalizedProperty.from_dict(obj["largeBrandedBannerImageImapScript"]) if obj.get("largeBrandedBannerImageImapScript") is not None else None,
            "largeBrandedBannerImageUrl": LocalizedProperty.from_dict(obj["largeBrandedBannerImageUrl"]) if obj.get("largeBrandedBannerImageUrl") is not None else None,
            "smallBrandedBannerImageImapScript": LocalizedProperty.from_dict(obj["smallBrandedBannerImageImapScript"]) if obj.get("smallBrandedBannerImageImapScript") is not None else None,
            "smallBrandedBannerImageUrl": LocalizedProperty.from_dict(obj["smallBrandedBannerImageUrl"]) if obj.get("smallBrandedBannerImageUrl") is not None else None,
            "trackingImageUrl": obj.get("trackingImageUrl"),
            "watchIconImageUrl": obj.get("watchIconImageUrl")
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictStr, field_validator
from typing import Optional
from typing_extensions import Annotated
from youtube_ti.models.video_trainability import VideoTrainability

from youtube_ti.api_client import ApiClient, RequestSerialized
from youtube_ti.api_response import ApiResponse
from youtube_ti.rest import RESTResponseType


class VideoTrainabilityApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def youtube_video_trainability_get(
        self,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        id: Annotated[Optional[StrictStr], Field(description="The ID of the video to retrieve.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> VideoTrainability:
        """youtube_video_trainability_get

        Returns the trainability status of a video.

        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param id: The ID of the video to retrieve.
        :type id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_video_trainability_get_serialize(
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            id=id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VideoTrainability",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def youtube_video_trainability_get_with_http_info(
        self,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        id: Annotated[Optional[StrictStr], Field(description="The ID of the video to retrieve.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[VideoTrainability]:
        """youtube_video_trainability_get

        Returns the trainability status of a video.

        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param id: The ID of the video to retrieve.
        :type id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_video_trainability_get_serialize(
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            id=id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VideoTrainability",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def youtube_video_trainability_get_without_preload_content(
        self,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        id: Annotated[Optional[StrictStr], Field(description="The ID of the video to retrieve.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """youtube_video_trainability_get

        Returns the trainability status of a video.

        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param id: The ID of the video to retrieve.
        :type id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_video_trainability_get_serialize(
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            id=id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VideoTrainability",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _youtube_video_trainability_get_serialize(
        self,
        oauth_token,
        key,
        upload_type,
        quota_user,
        upload_protocol,
        param_callback,
        fields,
        xgafv,
        pretty_print,
        access_token,
        alt,
        id,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if oauth_token is not None:
            
            _query_params.append(('oauth_token', oauth_token))
            
        if key is not None:
            
            _query_params.append(('key', key))
            
        if upload_type is not None:
            
            _query_params.append(('uploadType', upload_type))
            
        if quota_user is not None:
            
            _query_params.append(('quotaUser', quota_user))
            
        if upload_protocol is not None:
            
            _query_params.append(('upload_protocol', upload_protocol))
            
        if param_callback is not None:
            
            _query_params.append(('callback', param_callback))
            
        if fields is not None:
            
            _query_params.append(('fields', fields))
            
        if xgafv is not None:
            
            _query_params.append(('$.xgafv', xgafv))
            
        if pretty_print is not None:
            
            _query_params.append(('prettyPrint', pretty_print))
            
        if access_token is not None:
            
            _query_params.append(('access_token', access_token))
            
        if alt is not None:
            
            _query_params.append(('alt', alt))
            
        if id is not None:
            
            _query_params.append(('id', id))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    '*/*'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'Oauth2c', 
            'Oauth2'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/youtube/v3/videoTrainability',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )


